Index: includes/forums/template.php
--- includes/forums/template.php
+++ includes/forums/template.php
@@ -2245,8 +2245,8 @@
 	 * @uses bbp_is_forum_edit() To check if it's the forum edit page
 	 * @uses bbp_get_global_post_field() To get current post author
 	 * @uses bbp_get_current_user_id() To get the current user id
 	 * @uses bbp_is_user_subscribed() To check if the user is subscribed to
 	 *                the forum
 	 * @uses apply_filters() Calls 'bbp_get_form_forum_subscribed' with the
 	 *                option
 	 * @return string Checked value of forum subscription
@@ -2265,16 +2265,16 @@
 
 			// Post author is not the current user
 			if ( bbp_get_current_user_id() !== $post_author ) {
-				$forum_subscribed = bbp_is_user_subscribed( $post_author );
+				$forum_subscribed = bbp_is_user_subscribed_to_forum( $post_author );
 
 			// Post author is the current user
 			} else {
-				$forum_subscribed = bbp_is_user_subscribed( bbp_get_current_user_id() );
+				$forum_subscribed = bbp_is_user_subscribed_to_forum( bbp_get_current_user_id() );
 			}
 
 		// Get current status
 		} elseif ( bbp_is_single_forum() ) {
-			$forum_subscribed = bbp_is_user_subscribed( bbp_get_current_user_id() );
+			$forum_subscribed = bbp_is_user_subscribed_to_forum( bbp_get_current_user_id() );
 
 		// No data
 		} else {
@@ -2245,8 +2245,8 @@
 	 * @uses bbp_get_global_post_field() To get current post author
 	 * @uses bbp_get_current_user_id() To get the current user id
-	 * @uses bbp_is_user_subscribed() To check if the user is subscribed to
-	 *                the forum
+	 * @uses bbp_is_user_subscribed_to_forum() To check if the user is
+	 *                                          subscribed to the forum
 	 * @uses apply_filters() Calls 'bbp_get_form_forum_subscribed' with the
 	 *                option
Index: includes/topics/template.php
--- includes/topics/template.php
+++ includes/topics/template.php
@@ -3898,8 +3898,8 @@
 	 * @since bbPress (r2976)
 	 *
 	 * @uses bbp_is_topic_edit() To check if it's the topic edit page
 	 * @uses bbp_is_user_subscribed() To check if the user is subscribed to
 	 *                                 the topic
 	 * @uses apply_filters() Calls 'bbp_get_form_topic_subscribed' with the
 	 *                        option
 	 * @return string Checked value of topic subscription
@@ -3918,16 +3918,16 @@
 
 			// Post author is not the current user
 			if ( bbp_get_current_user_id() !== $post_author ) {
-				$topic_subscribed = bbp_is_user_subscribed( $post_author );
+				$topic_subscribed = bbp_is_user_subscribed_to_topic( $post_author );
 
 			// Post author is the current user
 			} else {
-				$topic_subscribed = bbp_is_user_subscribed( bbp_get_current_user_id() );
+				$topic_subscribed = bbp_is_user_subscribed_to_topic( bbp_get_current_user_id() );
 			}
 
 		// Get current status
 		} elseif ( bbp_is_single_topic() ) {
-			$topic_subscribed = bbp_is_user_subscribed( bbp_get_current_user_id() );
+			$topic_subscribed = bbp_is_user_subscribed_to_topic( bbp_get_current_user_id() );
 
 		// No data
 		} else {
@@ -3898,8 +3898,8 @@
 	 *
 	 * @uses bbp_is_topic_edit() To check if it's the topic edit page
-	 * @uses bbp_is_user_subscribed() To check if the user is subscribed to
-	 *                                 the topic
+	 * @uses bbp_is_user_subscribed_to_topic() To check if the user is
+	 *                                          subscribed to the topic
 	 * @uses apply_filters() Calls 'bbp_get_form_topic_subscribed' with the
 	 *                        option
